]> git.sesse.net Git - cubemap/blobdiff - client.h
Support the new METACUBE_FLAGS_NOT_SUITABLE_FOR_STREAM_START Metacube flag.
[cubemap] / client.h
index cd909e39e0032cc4fa23e317e389fdc1bb96f2da..490190bd90054ddb0b4a39c2e79262fa817c0d88 100644 (file)
--- a/client.h
+++ b/client.h
@@ -41,7 +41,7 @@ struct Client {
        std::string remote_addr;
        time_t connect_time;
 
-       enum State { READING_REQUEST, SENDING_HEADER, SENDING_DATA, SENDING_ERROR };
+       enum State { READING_REQUEST, SENDING_HEADER, SENDING_DATA, SENDING_ERROR, WAITING_FOR_KEYFRAME };
        State state;
 
        // The HTTP request, as sent by the client. If we are in READING_REQUEST,
@@ -64,9 +64,10 @@ struct Client {
 
        // Number of bytes we are into the stream (ie., the end of last send).
        // -1 means we want to send from the end of the backlog (the normal case),
+       // although only at a keyframe.
        // -2 means we want to send from the _beginning_ of the backlog.
// Once we go into SENDING_DATA, these negative values will be translated
// to real numbers.
        size_t stream_pos;
 
        // Number of bytes we've sent of data. Only relevant for SENDING_DATA.
@@ -64,9 +64,10 @@ struct Client {
        // -2 means we want to send from the _beginning_ of the backlog.
-       // Once we go into SENDING_DATA, these negative values will be translated
-       // to real numbers.
+       // Once we go into WAITING_FOR_KEYFRAME or SENDING_DATA, these negative
+       // values will be translated to real numbers.
        size_t stream_pos;
 